@@ -1,8 +1,8 @@
-__version__ = "1.0.1"
+__version__ = "1.0.3"
 from booru.gelbooru import Gelbooru
 from booru.rule34 import Rule34
 from booru.tbib import Tbib
 from booru.safebooru import Safebooru
 from booru.xbooru import Xbooru
-from booru.structures.realbooru import Realbooru
+from booru.structures import Realbooru
 from booru.utils import *
\ No newline at end of file
